package com.zd.exam.mapper;

import com.zd.exam.domain.ElPaper;
import com.zd.exam.domain.ElPaperQu;
import com.zd.exam.domain.vo.ElPaperAssessVo;

import java.util.List;
import java.util.Map;

/**
 * 试卷管理Mapper接口
 *
 * @author zd
 * @date 2021-08-31
 */
public interface ElPaperMapper {
    /**
     * 查询试卷管理
     *
     * @param id 试卷管理主键
     * @return 试卷管理
     */
    public ElPaper selectElPaperById(Long id);

    /**
     * 查询试卷管理列表
     *
     * @param elPaper 试卷管理
     * @return 试卷管理集合
     */
    public List<ElPaper> selectElPaperList(ElPaper elPaper);

    /**
     * 新增试卷管理
     *
     * @param elPaper 试卷管理
     * @return 结果
     */
    public int insertElPaper(ElPaper elPaper);

    /**
     * 修改试卷管理
     *
     * @param elPaper 试卷管理
     * @return 结果
     */
    public int updateElPaper(ElPaper elPaper);

    /**
     * 删除试卷管理
     *
     * @param id 试卷管理主键
     * @return 结果
     */
    public int deleteElPaperById(Long id);

    /**
     * 批量删除试卷管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElPaperByIds(Long[] ids);

    /**
     * 批量新增试卷考题
     *
     * @param elPaperQuList 试卷考题列表
     * @return 结果
     */
    public int batchElPaperQu(List<ElPaperQu> elPaperQuList);


    /**
     * 通过试卷管理主键删除试卷考题信息
     *
     * @param id 试卷管理ID
     * @return 结果
     */
    public int deleteElPaperQuByPaperId(Long id);

    int deleteElPaperQuByPaperIds(Long[] ids);

    int updateGiveOutState(Integer aBreak);

    String selectExamTitleByPaperId(Long paperId);

    List<ElPaper> selectElPaperListByCourseChapterId(ElPaper elPaper);

    List<ElPaperAssessVo> selectPaperAssessList(ElPaper elPaper);
}
